@@ -7,7 +7,7 @@
 #  define VTKIOEXODUS_NO_EXPORT
 #else
 #  ifndef VTKIOEXODUS_EXPORT
-#    ifdef vtkIOExodus_EXPORTS
+#    ifdef IOExodus_EXPORTS
         /* We are building this library */
 #      define VTKIOEXODUS_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,22 +23,29 @@
 
 #ifndef VTKIOEXODUS_DEPRECATED
 #  define VTKIOEXODUS_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOEXODUS_DEPRECATED_EXPORT VTKIOEXODUS_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOEXODUS_DEPRECATED_NO_EXPORT VTKIOEXODUS_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOEXODUS_NO_DEPRECATED
+#ifndef VTKIOEXODUS_DEPRECATED_EXPORT
+#  define VTKIOEXODUS_DEPRECATED_EXPORT VTKIOEXODUS_EXPORT VTKIOEXODUS_DEPRECATED
 #endif
 
-/* AutoInit implementations.  */
-#if defined(vtkIOExodus_INCLUDE)
-# include vtkIOExodus_INCLUDE
-#endif
-#if defined(vtkIOExodus_AUTOINIT)
-# include "vtkAutoInit.h"
-VTK_AUTOINIT(vtkIOExodus)
+#ifndef VTKIOEXODUS_DEPRECATED_NO_EXPORT
+#  define VTKIOEXODUS_DEPRECATED_NO_EXPORT VTKIOEXODUS_NO_EXPORT VTKIOEXODUS_DEPRECATED
 #endif
 
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOEXODUS_NO_DEPRECATED
+#    define VTKIOEXODUS_NO_DEPRECATED
+#  endif
 #endif
+
+/* AutoInit implementations. */
+#ifdef vtkIOExodus_AUTOINIT_INCLUDE
+#include vtkIOExodus_AUTOINIT_INCLUDE
+#endif
+#ifdef vtkIOExodus_AUTOINIT
+#include "vtkAutoInit.h"
+VTK_MODULE_AUTOINIT(vtkIOExodus)
+#endif
+
+#endif /* VTKIOEXODUS_EXPORT_H */
