@@ -7,7 +7,7 @@
 #  define VTKIOGEOMETRY_NO_EXPORT
 #else
 #  ifndef VTKIOGEOMETRY_EXPORT
-#    ifdef vtkIOGeometry_EXPORTS
+#    ifdef IOGeometry_EXPORTS
         /* We are building this library */
 #      define VTKIOGEOMETRY_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,22 +23,29 @@
 
 #ifndef VTKIOGEOMETRY_DEPRECATED
 #  define VTKIOGEOMETRY_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKIOGEOMETRY_DEPRECATED_EXPORT VTKIOGEOMETRY_EXPORT __attribute__ ((__deprecated__))
-#  define VTKIOGEOMETRY_DEPRECATED_NO_EXPORT VTKIOGEOMETRY_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKIOGEOMETRY_NO_DEPRECATED
+#ifndef VTKIOGEOMETRY_DEPRECATED_EXPORT
+#  define VTKIOGEOMETRY_DEPRECATED_EXPORT VTKIOGEOMETRY_EXPORT VTKIOGEOMETRY_DEPRECATED
 #endif
 
-/* AutoInit implementations.  */
-#if defined(vtkIOGeometry_INCLUDE)
-# include vtkIOGeometry_INCLUDE
-#endif
-#if defined(vtkIOGeometry_AUTOINIT)
-# include "vtkAutoInit.h"
-VTK_AUTOINIT(vtkIOGeometry)
+#ifndef VTKIOGEOMETRY_DEPRECATED_NO_EXPORT
+#  define VTKIOGEOMETRY_DEPRECATED_NO_EXPORT VTKIOGEOMETRY_NO_EXPORT VTKIOGEOMETRY_DEPRECATED
 #endif
 
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKIOGEOMETRY_NO_DEPRECATED
+#    define VTKIOGEOMETRY_NO_DEPRECATED
+#  endif
 #endif
+
+/* AutoInit implementations. */
+#ifdef vtkIOGeometry_AUTOINIT_INCLUDE
+#include vtkIOGeometry_AUTOINIT_INCLUDE
+#endif
+#ifdef vtkIOGeometry_AUTOINIT
+#include "vtkAutoInit.h"
+VTK_MODULE_AUTOINIT(vtkIOGeometry)
+#endif
+
+#endif /* VTKIOGEOMETRY_EXPORT_H */
